@@ -239,6 +239,11 @@ class StructuralPlacementListener(walker.RDLListener):
         # ... I assume that means if there are vregs inside a mem, then
         # memwidth inherits the max virtual reg regwidth?
         if 'memwidth' not in node.inst.properties:
+            if self.max_vreg_width == 0:
+                self.msg.error(
+                    "Width of memory component is unknown. Either assign 'memwidth', or instantiate a virtual register to define the memory's width.",
+                    node.inst.def_src_ref
+                )
             node.inst.properties['memwidth'] = self.max_vreg_width
 
         self.resolve_addresses(node)
@@ -447,6 +452,13 @@ class StructuralPlacementListener(walker.RDLListener):
 
             if child_node.inst.addr_offset is not None:
                 # Address is already known. Do not need to infer
+                # Still, check that it honors the requested alignment
+                if (child_node.raw_address_offset % prop_alignment) != 0:
+                    self.msg.error(
+                        "Address offset +0x%x of component '%s' must be aligned on a 0x%x byte boundary"
+                        % (child_node.raw_address_offset, child_node.inst_name, prop_alignment),
+                        child_node.inst.inst_src_ref
+                    )
                 prev_node = child_node
                 continue
 
